varianteval
"""""""""""

|GitHub release| |PyPI version varianteval|

.. |GitHub release| image:: https://img.shields.io/github/release/broadinstitute/varianteval.svg
   :target: https://github.com/broadinstitute/varianteval/releases/

.. |PyPI version varianteval| image:: https://img.shields.io/pypi/v/varianteval.svg
   :target: https://pypi.python.org/pypi/varianteval/

``varianteval`` is a Python library to facilitate the comparison of one or more VCFs against each other and/or truth datasets.

Installation
------------

``pip`` is recommended for ``varianteval`` installation.

::

   pip install varianteval

To install from Github source for development, the following commands can be run.

::

   git clone https://github.com/broadinstitute/varianteval.git
   pip install -e varianteval/

Getting Started
---------------

Don't! This API is currently in pre-pre-alpha form. Unless you're helping to developing this library, don't use it for anything!

Getting help
------------

The `varianteval documentation page <https://broadinstitute.github.io/varianteval/>`_ provides detailed descriptions of API usage and algorithmic details. If you encounter bugs or have questions/comments/concerns, please file an issue on our `Github page <https://github.com/broadinstitute/varianteval/issues>`_.

Developers' guide
-----------------

For information on contributing to ``varianteval`` development, visit our `developer documentation <DEVELOP.md>`_.
